Composition
===========

.. container:: subclasses

    *Subclasses*

    .. toctree::
       :maxdepth: 1

       AutodiffComposition
       CompositionFunctionApproximator
       ParameterEstimationComposition

    |

.. container:: related

    *Related*

    * `NodeRoles <NodeRole>`

    .. toctree::
       :maxdepth: 1

       Pathway
       CompositionInterfaceMechanism
       OptimizationControlMechanism
       Scheduling
       Visualization
       Report

.. automodule:: psyneulink.core.compositions.composition
   :members: Composition, NodeRole, Graph
   :private-members:
   :exclude-members: Parameters, show_structure, CompositionError, get_inputs_format, external_input_ports_of_all_input_nodes, external_input_ports
